# Step 1: Collect Data
### On this page
  * [Add Initial Data](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-collect-information#add-initial-data)
  * [Collect Data from Experts](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-collect-information#collect-data-from-experts)
  * [Required Data](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-collect-information#required-data)


Start by collecting initial information on how AI technologies, including AI agents, are currently used in your organization. Maintaining accurate and up-to-date information about AI is essential for managing an organization’s IT landscape.
